LifecycleStatus

Enum LifecycleStatus 

pub enum LifecycleStatus {
    Candidate,
    UnderReview,
    Accepted,
    Rejected,
    Superseded,
}
Candidate lifecycle shared by reviewable core extension objects.

Variants



Candidate

Proposed by an engine or actor, not accepted fact.



UnderReview

Awaiting or undergoing explicit review.



Accepted

Explicitly accepted for its declared scope.



Rejected

Explicitly rejected.



Superseded

Replaced by a later object.

Implementations

Source

impl LifecycleStatus

pub fn is_accepted(self) -> bool

Returns true when the object is accepted for its declared scope.