pub struct Capability {Show 13 fields
pub id: Id,
pub actor: Id,
pub operation: CapabilityOperation,
pub target_type: String,
pub target_refs: Vec<ObjectRef>,
pub contexts: Vec<Id>,
pub preconditions: Vec<Id>,
pub postconditions: Vec<Id>,
pub forbidden_effects: Vec<Description>,
pub required_review: Option<RequiredReview>,
pub validity_interval: Option<ValidityInterval>,
pub provenance: Provenance,
pub status: CapabilityStatus,
}Expand description
Actor-specific ability to operate on a target in a context.
Fields
id: IdCapability identifier.
actor: IdActor cell.
operation: CapabilityOperationOperation granted.
target_type: StringTarget type.
target_refs: Vec<ObjectRef>Target references.
contexts: Vec<Id>Valid contexts.
preconditions: Vec<Id>Preconditions.
postconditions: Vec<Id>Postconditions.
forbidden_effects: Vec<Description>Forbidden effects.
required_review: Option<RequiredReview>Required review.
validity_interval: Option<ValidityInterval>Validity interval.
provenance: ProvenanceCapability provenance.
status: CapabilityStatusCapability status.
Implementations
Sourceimpl Capability
impl Capability
Sourcepub fn validate_active_use(&self) -> Result<()>
pub fn validate_active_use(&self) -> Result<()>
Validates whether this capability may be used for a mutating operation.