pub struct OverlapWitness {
pub id: Id,
pub witness_kind: OverlapWitnessKind,
pub shared_structure: SharedStructure,
pub participant_mappings: Vec<ParticipantMapping>,
pub scope: Scope,
pub context: Id,
pub evidence: Vec<Id>,
pub confidence: Confidence,
pub status: ReviewStatus,
}Expand description
Reviewable evidence for what is shared inside a correspondence.
Fields
id: IdWitness identifier.
witness_kind: OverlapWitnessKindWitness kind.
Concrete shared structure.
participant_mappings: Vec<ParticipantMapping>Participant-to-shared-structure mappings.
scope: ScopeScope in which the witness applies.
context: IdContext in which the witness is valid.
evidence: Vec<Id>Evidence identifiers supporting the witness.
confidence: ConfidenceConfidence in the witness.
status: ReviewStatusReview status of this witness.
Implementations
Sourceimpl OverlapWitness
impl OverlapWitness
Sourcepub fn supports_accepted_semantic_overlap(&self) -> bool
pub fn supports_accepted_semantic_overlap(&self) -> bool
Returns true when this witness can support an accepted semantic overlap.